@@ -17,7 +17,7 @@ use Data::Identifier;
 
 use parent qw(Data::Identifier::Interface::Userdata);
 
-our $VERSION = v0.01;
+our $VERSION = v0.02;
 
 
 sub new {
@@ -30,9 +30,8 @@ sub new {
         if ($data =~ /^[12][0-9]{3}(?:-[0-9]{2}(?:-[0-9]{2})?)?Z?$/) {
             $type = 'iso8601';
         } elsif ($data eq 'now') {
-            my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime;
-            $data = sprintf('%04u-%02u-%02uZ', $year + 1900, $mon, $mday);
-            $type = 'iso8601';
+            $data = time();
+            $type = 'epoch';
         } else {
             croak 'Invalid data: '.$data;
         }
@@ -41,8 +40,11 @@ sub new {
     if ($type eq 'datecode' && $data =~ /^(0|[1-9][0-9]*)$/) {
         my $code = int $data;
         return bless(\$code, $pkg);
+    } elsif ($type eq 'epoch' && $data =~ /^(0|[1-9][0-9]*)$/) {
+        my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime(int($data));
+        $iso = sprintf('%04u-%02u-%02uZ', $year + 1900, $mon, $mday);
     } elsif ($type eq 'iso8601' && $data =~ /^[12][0-9]{3}(?:-[0-9]{2}(?:-[0-9]{2})?)?Z?$/) {
-            $iso = $data;
+        $iso = $data;
     } else {
         croak 'Invalid type/data: '.$type;
     }
@@ -115,6 +117,15 @@ sub iso8601 {
     return $iso;
 }
 
+
+sub as {
+    my ($self, $as, %opts) = @_;
+
+    require Data::Identifier::Generate;
+
+    return Data::Identifier::Generate->date($self->iso8601)->as($as, %opts);
+}
+
 # ---- Private helpers ----
 
 sub _build_from_iso {
@@ -164,7 +175,7 @@ SIRTX::Datecode - module for interacting with SIRTX Datecodes
 
 =head1 VERSION
 
-version v0.01
+version v0.02
 
 =head1 SYNOPSIS
 
@@ -196,6 +207,10 @@ An ISO-8601 date string (C<YYYY-MM-DD>, C<YYYY-MM>, or C<YYYY>, all optionally s
 
 A datecode value (as integer).
 
+=item C<epoch>
+
+An epoch value as returned by L<perlfunc/time>.
+
 =back
 
 The special value C<from> is also supported as C<$type>.
@@ -217,6 +232,14 @@ Returns the datecode as an integer date code.
 
 Returns the datecode as an ISO-8601 date string.
 
+=head2 as
+
+    my $res = $dc->as($as, %opts);
+
+(experimental since v0.02)
+
+This is a proxy for L<Data::Identifier/as>.
+
 =head1 AUTHOR
 
 Löwenfelsen UG (haftungsbeschränkt) <support@loewenfelsen.net>
